ApiSpecFileName

Enum ApiSpecFileName 

pub enum ApiSpecFileName {
    Lockstep(LockstepApiSpecFileName),
    Versioned(VersionedApiSpecFileName),
}
Describes the path to an OpenAPI document file, relative to some root where similar documents are found.

Variants



Lockstep(LockstepApiSpecFileName)

A lockstep API: single OpenAPI document, no versioning.



Versioned(VersionedApiSpecFileName)

A versioned API: multiple versions can coexist.

Implementations

Source

impl ApiSpecFileName

pub fn ident(&self) -> &ApiIdent

Returns the API identifier.

pub fn path(&self) -> Utf8PathBuf

Returns the path of this file relative to the root of the OpenAPI documents.

pub fn basename(&self) -> String

Returns the base name of this file path.

pub fn version(&self) -> Option<&Version>

For versioned APIs, returns the version part of the filename.

pub fn hash(&self) -> Option<&str>

For versioned APIs, returns the hash part of the filename.

pub fn is_git_stub(&self) -> bool

Returns true if this is a Git stub.

pub fn versioned_kind(&self) -> Option<VersionedApiSpecKind>

For versioned APIs, returns the kind of storage.

pub fn to_json_filename(&self) -> ApiSpecFileName

Converts a Git stubname to its JSON equivalent.

For non-Git stubs, returns a clone of self.

pub fn to_git_stub_filename(&self) -> ApiSpecFileName

Converts a JSON filename to its Git stub equivalent.

For Git stubs, returns a clone of self. For lockstep files, returns a clone of self (lockstep files are not converted to Git stubs).

pub fn git_stub_basename(&self) -> String

Returns the basename for this file as a Git stub.

  • If this is already a Git stub, returns basename() directly.
  • If this is a versioned JSON file, returns basename() + ".gitstub".
  • For lockstep, returns basename() (lockstep files are not converted to Git stubs).
pub fn json_basename(&self) -> String

Returns the basename for this file as a JSON file.

  • If this is a Git stub, returns the basename without the .gitstub suffix.
  • Otherwise, returns basename() directly.
pub fn as_versioned(&self) -> Option<&VersionedApiSpecFileName>

Returns a reference to the inner VersionedApiSpecFileName if this is a versioned API, or None if this is a lockstep API.

pub fn into_versioned(self) -> Option<VersionedApiSpecFileName>

Consumes self and returns the inner VersionedApiSpecFileName if this is a versioned API, or None if this is a lockstep API.

pub fn as_lockstep(&self) -> Option<&LockstepApiSpecFileName>

Returns a reference to the inner LockstepApiSpecFileName if this is a lockstep API, or None if this is a versioned API.

pub fn into_lockstep(self) -> Option<LockstepApiSpecFileName>

Consumes self and returns the inner LockstepApiSpecFileName if this is a lockstep API, or None if this is a versioned API.