Versions

Enum Versions 

pub enum Versions {
    Lockstep {
        version: Version,
    },
    Versioned {
        supported_versions: SupportedVersions,
    },
}
Describes how an API is versioned

Variants



Lockstep

There is only ever one version of this API

Clients and servers are updated at runtime in lockstep.

Fields

version: Version


Versioned

There are multiple supported versions of this API

Clients and servers may be updated independently of each other. Other parts of the system may constrain things so that either clients or servers are always updated first, but this tool does not assume that.

Fields

supported_versions: SupportedVersions

Implementations

Source

impl Versions

pub fn new_lockstep(version: Version) -> Versions

Constructor for a lockstep API

pub fn new_versioned(supported_versions: SupportedVersions) -> Versions

Constructor for a versioned API

pub fn is_versioned(&self) -> bool

Returns whether this API is versioned (as opposed to lockstep)

pub fn is_lockstep(&self) -> bool

Returns whether this API is lockstep (as opposed to versioned)

pub fn iter_versions_semvers(&self) -> IterVersionsSemvers<'_>

Iterate over the semver versions of an API that are supported

pub fn iter_versioned_versions( &self, ) -> Option<impl Iterator<Item = &SupportedVersion> + '_>

For versioned APIs only, iterate over the SupportedVersions