pub struct ApiSpecFileName { /* private fields */ }Expand description
Describes the path to an OpenAPI document file, relative to some root where similar documents are found
Implementations
Sourceimpl ApiSpecFileName
impl ApiSpecFileName
pub fn ident(&self) -> &ApiIdent
pub fn kind(&self) -> &ApiSpecFileNameKind
Sourcepub fn path(&self) -> Utf8PathBuf
pub fn path(&self) -> Utf8PathBuf
Returns the path of this file relative to the root of the OpenAPI documents