VersionedApiSpecFileName

Struct VersionedApiSpecFileName 

pub struct VersionedApiSpecFileName { /* private fields */ }
A versioned API spec filename.

Versioned APIs can have multiple versions coexisting. The filename includes the version and a content hash: {ident}/{ident}-{version}-{hash}.json (or .json.gitstub for Git stub storage).

Implementations

Source

impl VersionedApiSpecFileName

pub fn new(ident: ApiIdent, version: Version, hash: String) -> Self

Creates a new versioned API spec filename (JSON format).

pub fn new_git_stub(ident: ApiIdent, version: Version, hash: String) -> Self

Creates a new versioned API spec filename (Git stub format).

pub fn ident(&self) -> &ApiIdent

Returns the API identifier.

pub fn version(&self) -> &Version

Returns the version.

pub fn hash(&self) -> &str

Returns the hash.

pub fn kind(&self) -> VersionedApiSpecKind

Returns the storage kind (JSON or Git stub).

pub fn is_git_stub(&self) -> bool

Returns true if this is a Git stub.

pub fn path(&self) -> Utf8PathBuf

Returns the path of this file relative to the root of the OpenAPI documents.

pub fn basename(&self) -> String

Returns the base name of this file path.

pub fn to_json(&self) -> Self

Converts this filename to its JSON equivalent.

If already JSON, returns a clone of self.

pub fn to_git_stub(&self) -> Self

Converts this filename to its Git stub equivalent.

If already a Git stub, returns a clone of self.

pub fn git_stub_basename(&self) -> String

Returns the basename as a Git stubname.

  • If already a Git stub, returns basename() directly.
  • If JSON, returns basename() + ".gitstub".
pub fn json_basename(&self) -> String

Returns the basename as a JSON filename.

  • If already JSON, returns basename() directly.
  • If Git stub, returns the basename without .gitstub.