Crate dropshot_api_manager_types

Crate dropshot_api_manager_types 

Shared types for the Dropshot API manager.

This crate is part of the Dropshot OpenAPI manager.

Code that defines API traits can depend on dropshot-api-manager-types to get access to interfaces exposed by the Dropshot API manager. In particular, versioned APIs will want to depend on this crate for access to the api_versions! macro.

Re-exports

pub use semver;

Macros

api_versions
Helper macro used to define API versions.
api_versions_picky
“picky” version of api_versions that lets you specify the minor and patch numbers, too
paste

Structs

ApiIdent
Newtype for API identifiers
IterVersionsSemvers
LockstepApiSpecFileName
A lockstep API spec filename.
ManagedApiMetadata
Optional metadata that’s part of a ManagedApiConfig.
SupportedVersion
SupportedVersions
ValidationContext
Context for validation of OpenAPI documents.
VersionedApiSpecFileName
A versioned API spec filename.

Enums

ApiSpecFileName
Describes the path to an OpenAPI document file, relative to some root where similar documents are found.
VersionedApiSpecKind
Describes how a versioned API spec file is stored.
Versions
Describes how an API is versioned