Crate dropshot_api_manager_types

Crate dropshot_api_manager_types 

Shared types for the Dropshot API manager.

This crate is part of the Dropshot OpenAPI manager.

Code that defines API traits can depend on dropshot-api-manager-types to get access to interfaces exposed by the Dropshot API manager. In particular, versioned APIs will want to depend on this crate for access to the api_versions! macro.

Re-exports

pub use semver;

Macros

api_versions
Helper macro used to define API versions.
api_versions_picky
“picky” version of api_versions that lets you specify the minor and patch numbers, too
paste

Structs

ApiIdent
Newtype for API identifiers
ApiSpecFileName
Describes the path to an OpenAPI document file, relative to some root where similar documents are found
IterVersionsSemvers
ManagedApiMetadata
Optional metadata that’s part of a ManagedApiConfig.
SupportedVersion
SupportedVersions
ValidationContext
Context for validation of OpenAPI specifications.

Enums

ApiSpecFileNameKind
Describes how a particular OpenAPI document is named.
Versions
Describes how an API is versioned