pub struct ValidationContext<'a> { /* private fields */ }Expand description
Context for validation of OpenAPI specifications.
Implementations
Sourceimpl<'a> ValidationContext<'a>
impl<'a> ValidationContext<'a>
Sourcepub fn ident(&self) -> &ApiIdent
pub fn ident(&self) -> &ApiIdent
Retrieves the identifier of the API being validated.
This identifier is set via the OpenAPI manager’s ManagedApiConfig
type.
Sourcepub fn file_name(&self) -> &ApiSpecFileName
pub fn file_name(&self) -> &ApiSpecFileName
Returns a descriptor for the API’s file name.
Sourcepub fn metadata(&self) -> &ManagedApiMetadata
pub fn metadata(&self) -> &ManagedApiMetadata
Retrieves optional metadata for the API being validated.
Sourcepub fn report_error(&mut self, error: Error)
pub fn report_error(&mut self, error: Error)
Reports a validation error.
Sourcepub fn record_file_contents(
&mut self,
path: impl Into<Utf8PathBuf>,
contents: Vec<u8>,
)
pub fn record_file_contents( &mut self, path: impl Into<Utf8PathBuf>, contents: Vec<u8>, )
Records that the file has the given contents.
In check mode, if the files differ, an error is logged.
In generate mode, the file is overwritten with the given contents.
The path is treated as relative to the root of the repository.