ValidationContext

Struct ValidationContext 

pub struct ValidationContext<'a> { /* private fields */ }
Context for validation of OpenAPI specifications.

Implementations

Source

impl<'a> ValidationContext<'a>

pub fn ident(&self) -> &ApiIdent

Retrieves the identifier of the API being validated.

This identifier is set via the OpenAPI manager’s ManagedApiConfig type.

pub fn file_name(&self) -> &ApiSpecFileName

Returns a descriptor for the API’s file name.

pub fn versions(&self) -> &Versions

Retrieves the versioning strategy for this API.

pub fn title(&self) -> &str

Retrieves the title of the API being validated.

pub fn metadata(&self) -> &ManagedApiMetadata

Retrieves optional metadata for the API being validated.

pub fn report_error(&mut self, error: Error)

Reports a validation error.

pub fn record_file_contents( &mut self, path: impl Into<Utf8PathBuf>, contents: Vec<u8>, )

Records that the file has the given contents.

In check mode, if the files differ, an error is logged.

In generate mode, the file is overwritten with the given contents.

The path is treated as relative to the root of the repository.